Find Us – Soka Gakkai International - USA
Author: Soka Gakkai International - USA
Description: Nichiren Buddhism for Daily Life

 Soka Gakkai International - USA
Nichiren Buddhism for Daily Life
Find or Contact an SGI-USA Center

## Search by City or Zip.

Find Locations Near:
Street: | City: | State:
City or Zip: |  |
Select a distance: |  |
Categories | Central East West |

Use the toggles to zoom + click and drag to navigate the map above.

## Local SGI-USA Websites.

East Central West
East Territory

- New York Culture Center
- Philadelphia Center
- Washington, D.C. Culture Center
- Queens Center

Central Territory

- Chicago Culture Center
- Phoenix Center
- Minnesota Center
- Denver Culture Center

West Territory

- Los Angeles Friendship Center
- Santa Ana Center
- South Bay Center
- Silicon Valley Center

## I am looking for the SGI-USA near me.

Disclaimer before you visit: “Many community centers are not open during regular office hours or weekdays. Please call first before you visit.”
*Must fill out all fields with an asterisk (*).

How can we help narrow your search?
Name *
Email *
Phone Number
City *
State *
Current District
Current Chapter
Additional Comments
Thanks for contacting us, we'll get back to you as soon as we can!
SGI-USA National and Territory Contact Information

## Contact the SGI-USA.

National Headquarters

606 Wilshire Blvd.
Santa Monica, CA 90401
P: (310) 260.8900 – F: (310) 260.8917

Email Us Here

East Territory

7 East 15th Street
New York, NY 10003
P: (212)727.7715 – F: (212)727.7712

Email Us Here

Central Territory

1455 South Wabash Ave,
Chicago IL 60605
P: (312)913.1211 – F: (312)913.0988

Email Us Here

West Territory

5899 Venice Blvd.
Los Angeles, CA 90019

P: (323)965.0025 – F: (323)965.0054

Email Us Here

FNCC

P: (954)349.5000

View 2014 Conference Schedule
Email Us Here

Press Inquiries

Bill Aiken, Director of Public Affairs
3417 Massachusetts, NW
Washington, DC 20007

Email Us Here

SGI-Related Books & Accessories

Purchase Items at our SGI-USA Online Store

Questions / Concerns regarding orders please email: mailorder@sgi-usa.org

Publications & Subscriptions

Visit World Tribune or Living Buddhism to update your address or billing information.

For submissions to any of the foreign language supplements for The World Tribune, submit them to wt@sgi-usa.org

Contributions

If you would like to help contribute to the growth of SGI-USA,

Contribute Here

Seeking a SGI location outside of the United States?

## I am a SGI-USA member relocating/traveling to another country.

Please obtain a Letter of Introduction from your territory office and take it with you to the country to which you are visiting or relocating.

## Countries and Territories where there are SGI Members

The entire list of 192 countries and territories in which there are practicing members is not released publicly. This is because certain countries on this list (for religious, social or political reasons) may be sensitive to having us publicly announce that there are Buddhists practicing in their borders. However, we maintain a list of 93 registered constituent SGI organizations.